AllergensTag enum
Main allergens.
Values
- GLUTEN → const AllergensTag
-
const AllergensTag(offTag: 'en:gluten') - MILK → const AllergensTag
-
const AllergensTag(offTag: 'en:milk') - EGGS → const AllergensTag
-
const AllergensTag(offTag: 'en:eggs') - NUTS → const AllergensTag
-
const AllergensTag(offTag: 'en:nuts') - PEANUTS → const AllergensTag
-
const AllergensTag(offTag: 'en:peanuts') - SESAME_SEEDS → const AllergensTag
-
const AllergensTag(offTag: 'en:sesame-seeds') - SOYBEANS → const AllergensTag
-
const AllergensTag(offTag: 'en:soybeans') - CELERY → const AllergensTag
-
const AllergensTag(offTag: 'en:celery') - MUSTARD → const AllergensTag
-
const AllergensTag(offTag: 'en:mustard') - LUPIN → const AllergensTag
-
const AllergensTag(offTag: 'en:lupin') - FISH → const AllergensTag
-
const AllergensTag(offTag: 'en:fish') - CRUSTACEANS → const AllergensTag
-
const AllergensTag(offTag: 'en:crustaceans') - MOLLUSCS → const AllergensTag
-
const AllergensTag(offTag: 'en:molluscs') - SULPHUR_DIOXIDE_AND_SULPHITES → const AllergensTag
-
const AllergensTag(offTag: 'en:sulphur-dioxide-and-sulphites')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - offTag → String
-
Identifying tag used in the rest of OFF.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AllergensTag> - A constant List of the values in this enum, in order of their declaration.