ImageSize enum

Inheritance
Implemented types
Available extensions

Values

THUMB → const ImageSize

Width and height <= 100 px

const ImageSize(offTag: 'thumb', number: '100')
SMALL → const ImageSize

Width and height <= 200 px

const ImageSize(offTag: 'small', number: '200')
DISPLAY → const ImageSize

Width and height <= 400 px

const ImageSize(offTag: 'display', number: '400')
ORIGINAL → const ImageSize

Width and height: as uploaded

const ImageSize(offTag: 'original', number: 'full')
UNKNOWN → const ImageSize

Size not available

const ImageSize(offTag: 'unknown', number: 'unknown')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
number String
final
offTag String
Identifying tag used in the rest of OFF.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String

Available on ImageSize?, provided by the ImageSizeExtension extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNumber() String

Available on ImageSize?, provided by the ImageSizeExtension extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ImageSize>
A constant List of the values in this enum, in order of their declaration.