State enum
States of a Product. To be used in search API, with StatesTagsParameter.
Provides tags for State and its status: completed or to-be-completed.
Values
- CHECKED → const State
-
const State(completedTag: 'en:checked', toBeCompletedTag: 'en:to-be-checked') - COMPLETED → const State
-
const State(completedTag: 'en:complete', toBeCompletedTag: 'en:to-be-completed') - NUTRITION_FACTS_COMPLETED → const State
-
const State.completed(tag: 'en:nutrition-facts') - INGREDIENTS_COMPLETED → const State
-
const State.completed(tag: 'en:ingredients') - EXPIRATION_DATE_COMPLETED → const State
-
const State.completed(tag: 'en:expiration-date') - PACKAGING_CODE_COMPLETED → const State
-
const State.completed(tag: 'en:packaging-code') - CHARACTERISTICS_COMPLETED → const State
-
const State.completed(tag: 'en:characteristics') - ORIGINS_COMPLETED → const State
-
const State.completed(tag: 'en:origins') - CATEGORIES_COMPLETED → const State
-
const State.completed(tag: 'en:categories') - BRANDS_COMPLETED → const State
-
const State.completed(tag: 'en:brands') - PACKAGING_COMPLETED → const State
-
const State.completed(tag: 'en:packaging') - QUANTITY_COMPLETED → const State
-
const State.completed(tag: 'en:quantity') - PRODUCT_NAME_COMPLETED → const State
-
const State.completed(tag: 'en:product-name') - PHOTOS_VALIDATED → const State
-
const State.simple(tag: 'en:photos', action: 'validated') - PACKAGING_PHOTO_SELECTED → const State
-
const State.selected(tag: 'en:packaging-photo') - NUTRITION_PHOTO_SELECTED → const State
-
const State.selected(tag: 'en:nutrition-photo') - INGREDIENTS_PHOTO_SELECTED → const State
-
const State.selected(tag: 'en:ingredients-photo') - FRONT_PHOTO_SELECTED → const State
-
const State.selected(tag: 'en:front-photo') - PHOTOS_UPLOADED → const State
-
const State.simple(tag: 'en:photos', action: 'uploaded')
Properties
- completedTag → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toBeCompletedTag → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited