GetUsersOrderField enum
Field for the "order by" clause of "get users".
- Inheritance
- Implemented types
- Available extensions
Values
- priceCount → const GetUsersOrderField
-
const GetUsersOrderField(offTag: 'price_count') - userId → const GetUsersOrderField
-
const GetUsersOrderField(offTag: 'user_id')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - offTag → String
-
Identifying tag used in the rest of OFF.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
GetUsersOrderField> - A constant List of the values in this enum, in order of their declaration.