TagFilterType enum
Filter types for advanced search parameters
Values
- BRANDS → const TagFilterType
-
const TagFilterType(offTag: 'brands') - CATEGORIES → const TagFilterType
-
const TagFilterType(offTag: 'categories') - PACKAGING → const TagFilterType
-
const TagFilterType(offTag: 'packaging') - LABELS → const TagFilterType
-
const TagFilterType(offTag: 'labels') - ORIGINS → const TagFilterType
-
const TagFilterType(offTag: 'origins') - MANUFACTURING_PLACES → const TagFilterType
-
const TagFilterType(offTag: 'manufacturing_places') - EMB_CODES → const TagFilterType
-
const TagFilterType(offTag: 'emb_codes') - PURCHASE_PLACES → const TagFilterType
-
const TagFilterType(offTag: 'purchase_places') - STORES → const TagFilterType
-
const TagFilterType(offTag: 'stores') - COUNTRIES → const TagFilterType
-
const TagFilterType(offTag: 'countries') - ADDITIVES → const TagFilterType
-
const TagFilterType(offTag: 'additives') - ALLERGENS → const TagFilterType
-
const TagFilterType(offTag: 'allergens') - TRACES → const TagFilterType
-
const TagFilterType(offTag: 'traces') - NUTRITION_GRADES → const TagFilterType
-
const TagFilterType(offTag: 'nutrition_grades') - STATES → const TagFilterType
-
const TagFilterType(offTag: 'states') - INGREDIENTS → const TagFilterType
-
const TagFilterType(offTag: 'ingredients') - NOVA_GROUPS → const TagFilterType
-
const TagFilterType(offTag: 'nova_groups') - LANGUAGES → const TagFilterType
-
const TagFilterType(offTag: 'languages') - CREATOR → const TagFilterType
-
User who created this product
const TagFilterType(offTag: 'creator') - EDITORS → const TagFilterType
-
const TagFilterType(offTag: 'editors') - PHOTOGRAPHERS → const TagFilterType
-
User who photographed for this product
const TagFilterType(offTag: 'photographers') - INFORMERS → const TagFilterType
-
Users who contributed to this product
const TagFilterType(offTag: 'informers') - LANG → const TagFilterType
-
const TagFilterType(offTag: 'lang')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - offTag → String
-
Identifying tag used in the rest of OFF.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TagFilterType> - A constant List of the values in this enum, in order of their declaration.